==> kv5500-0.3.tar.gz: kv5500-0.3/src/gkv5500_file.hpp <==
/*****************************************************************************
 *
 *  gkv5500 - gtk2 frontend of kv5500 utility.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef GKV5500_FILE_H
#define GKV5500_FILE_H

#include <gtk/gtk.h>

#include "kv5500_file.hpp"

namespace KV5500 {

    class GGetFileScanner : public GetFileScanner {
    public:
        GGetFileScanner(unsigned int num, const std::string& filename, GtkWidget* label, GtkWidget* progressBar);

        virtual ~GGetFileScanner() = 0;

    private:
        std::string filename_;
        GtkWidget* label_;
        GtkWidget* progressBar_;

        void PrintError(const std::string& msg);
        void Print(const std::string& msg);
        void PrintProcess(unsigned int complete, unsigned int total);
        void PrintEnd(const std::string& msg);

        std::string GetFilename() const;

        GGetFileScanner(const GGetFileScanner&);
        GGetFileScanner& operator=(const GGetFileScanner&);
    };
}

#endif

==> kv5500-0.3.1.tar.gz: kv5500-0.3.1/src/gkv5500_file.hpp <==
/*****************************************************************************
 *
 *  gkv5500 - gtk2 frontend of kv5500 utility.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef GKV5500_FILE_H
#define GKV5500_FILE_H

#include <gtk/gtk.h>

#include "kv5500_file.hpp"

namespace KV5500 {

    class CopyFilenameGenerator {
    public:
        CopyFilenameGenerator(const std::string& filename);

        std::string GetFilename(unsigned int) const;
    private:
        const std::string& filename_;

        CopyFilenameGenerator(const CopyFilenameGenerator&);
        CopyFilenameGenerator& operator=(const CopyFilenameGenerator&);
    };

    class GtkDisplay {
    public:
        GtkDisplay(GtkWidget* label, GtkWidget* progressBar);

        void PrintError(const std::string& msg);
        void PrintError(const char* msg);
        void Print(const std::string& msg);
        void PrintProcess(unsigned int complete, unsigned int total);
        void PrintEnd(const std::string& msg);

    private:
        GtkWidget* const label_;
        GtkWidget* const progressBar_;

        GtkDisplay(const GtkDisplay&);
        GtkDisplay& operator=(const GtkDisplay);
    };
}

/// inline functions.
using namespace KV5500;

inline CopyFilenameGenerator::CopyFilenameGenerator(const std::string& filename)
    : filename_(filename)
{}

inline std::string CopyFilenameGenerator::GetFilename(unsigned int) const
{
    return filename_;
}

inline GtkDisplay::GtkDisplay(GtkWidget* label, GtkWidget* progressBar)
    : label_(label),
      progressBar_(progressBar)
{
    assert(label && progressBar);

    gtk_widget_set_sensitive(progressBar_, TRUE);
}

inline void GtkDisplay::PrintError(const std::string& msg)
{
    PrintError(msg.c_str());
}

#endif
